'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

exports.default = function () {
    var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

    var _ref$configFile = _ref.configFile;
    var configFile = _ref$configFile === undefined ? null : _ref$configFile;
    var _ref$policy = _ref.policy;
    var policy = _ref$policy === undefined ? [{
        userAgent: '*',
        allow: '/'
    }] : _ref$policy;
    var _ref$sitemap = _ref.sitemap;
    var sitemap = _ref$sitemap === undefined ? null : _ref$sitemap;
    var _ref$crawlDelay = _ref.crawlDelay;
    var crawlDelay = _ref$crawlDelay === undefined ? null : _ref$crawlDelay;
    var _ref$host = _ref.host;
    var host = _ref$host === undefined ? null : _ref$host;
    var _ref$cleanParam = _ref.cleanParam;
    var cleanParam = _ref$cleanParam === undefined ? null : _ref$cleanParam;

    var options = {
        policy: policy,
        sitemap: sitemap,
        crawlDelay: crawlDelay,
        host: host,
        cleanParam: cleanParam
    };

    var starter = null;

    if (!configFile) {
        starter = Promise.resolve();
    } else {
        starter = new Promise(function (resolve) {
            var optionsFromConfigFile = require(configFile); // eslint-disable-line global-require

            options = Object.assign({}, options, optionsFromConfigFile.default ? optionsFromConfigFile.default : optionsFromConfigFile);

            return resolve();
        });
    }

    return starter.then(function () {
        return new Promise(function (resolve, reject) {
            if (!Array.isArray(options.policy)) {
                return reject(new Error('Options `policy` must be array'));
            }

            if (Array.isArray(host)) {
                return reject(new Error('Options `host` must be one'));
            }

            if (typeof options.crawlDelay !== 'number' && !isFinite(options.crawlDelay)) {
                return reject(new Error('Options `crawlDelay` must be integer or float'));
            }

            var contents = '';

            options.policy.forEach(function (item) {
                contents += addLine(item);
            });

            if (options.sitemap) {
                contents += addLine('Sitemap', options.sitemap);
            }

            if (options.host) {
                contents += addLine('Host', options.host);
            }

            if (options.crawlDelay) {
                contents += addLine('Crawl-delay', options.crawlDelay);
            }

            if (options.cleanParam) {
                contents += addLine('Clean-param', options.cleanParam);
            }

            return resolve(contents);
        });
    });
};

function capitaliseFirstLetter(string) {
    return string.charAt(0).toUpperCase() + string.slice(1);
}

function addLine(name, rule) {
    var contents = '';

    if (Object.prototype.toString.call(name) === '[object Object]') {
        Object.keys(name).forEach(function (key) {
            var value = name[key];

            contents += addLine(key, value);
        });
    } else if (rule && Object.prototype.toString.call(rule) === '[object Array]') {
        rule.forEach(function (item) {
            contents += addLine(name, item);
        });
    } else {
        contents += capitaliseFirstLetter(name.replace(/([a-z])([A-Z])/g, '$1-$2').toLowerCase()) + ': ' + rule + '\n';
    }

    return contents;
}